@@ -4,6 +4,8 @@
 ( cd opt/kde/share/doc/HTML/ru/kugar ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kword ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/koffice ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/koffice ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/koshell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/koshell ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kspread ; rm -rf common )
